import { renderless, api } from '@opentinyvue/vue-renderless/tag-group/vue';
import { defineComponent, $prefix, $props, setup } from '@opentinyvue/vue-common';
import { IconEllipsis } from '@opentinyvue/vue-icon';
import Popover from '@opentinyvue/vue-popover';
import Tag from '@opentinyvue/vue-tag';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
var __vue2_script = defineComponent({
  name: $prefix + "TagGroup",
  emits: ["item-click"],
  props: _extends({}, $props, {
    size: {
      type: String,
      default: "medium",
      validator: function validator(value) {
        return ~["medium", "small", "mini"].indexOf(value);
      }
    },
    data: {
      type: Array,
      default: function _default() {
        return [];
      }
    },
    effect: {
      type: String,
      default: "light",
      validator: function validator2(value) {
        return ~["dark", "light", "plain"].indexOf(value);
      }
    }
  }),
  components: {
    TinyTag: Tag,
    TinyPopover: Popover,
    IconEllipsis: IconEllipsis()
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    ref: "tagGroup",
    staticClass: "overflow-hidden relative pr-8",
    attrs: {
      "data-tag": "tiny-tag-group"
    }
  }, [_vm._l(_vm.data, function(item, i) {
    return _c("tiny-tag", {
      key: item.name + i,
      attrs: {
        "size": _vm.size,
        "type": item.type || "info",
        "effect": _vm.effect
      },
      on: {
        "click": function click($event) {
          return _vm.handelItemClick(item, i, $event);
        }
      }
    }, [_vm._v(_vm._s(item.name))]);
  }), _c("tiny-popover", {
    staticClass: "absolute top-0 right-0",
    attrs: {
      "placement": "top-start",
      "trigger": "hover"
    },
    scopedSlots: _vm._u([{
      key: "reference",
      fn: function fn() {
        return [_c("div", {
          staticClass: "absolute top-0 right-0 pointer-events-none sm:pointer-events-auto",
          class: [_vm.state.showMore ? "block" : "invisible"]
        }, [_c("tiny-tag", {
          ref: "more",
          attrs: {
            "size": _vm.size,
            "type": "info",
            "customClass": "px-1.5 mr-0"
          }
        }, [_c("icon-ellipsis", {
          staticClass: "fill-color-icon-secondary"
        })], 1)], 1)];
      },
      proxy: true
    }])
  }, [_c("div", {
    attrs: {
      "data-tag": "tiny-tag-group-popover"
    }
  }, _vm._l(_vm.state.hiddenTags, function(tag, i) {
    return _c("tiny-tag", {
      key: tag.name + i,
      attrs: {
        "size": _vm.size,
        "type": tag.type || "info",
        "customClass": "mb-2"
      },
      on: {
        "click": function click($event) {
          return _vm.handelItemClick(tag, _vm.data.length - _vm.state.hiddenTags.length + i, $event);
        }
      }
    }, [_vm._v(_vm._s(tag.name))]);
  }), 1)])], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
